Blood for Bludd!

# The Brutal Scriptures of Bludd, the Blood God (of Blood)

## As compiled by Grodnir the Voracious, Slaughtermaster of Bludd

And so it came to pass that Fjordlak the Annihilator, who once bathed in the rejuvenating blood
of a hundred warriors, was buried alive.

Experts at the Red Cross understand that blood must be lost for the righteous to survive

In the eyes of Bludd, the strong and the bold appear the same.
But the sages have ordained that to be strong implies greater meaning than to be merely bold. So it is written.

And his castle, in which so many heroic deeds took place, fell rapidly into ruin.

Power
Glory
Blood

    Fjordlak's enemies howled forlonly as their bodies
    were heaped	high
    for the glory of Bludd!!!

> The raging roars of Fjordlak shattered the tyrant's grasp on our people!

Strong was the hand of Fjordlak!

H2O
13C NMR

BLUDD

Have questions about Bludd? Call Grodnir the Voracious at Blood4Blud!

If your browser supports bi-directional override (bdo), the next line will be written from right to left (rtl):

This line will be written from right to left

this text's color was set with hex color encoding.